""" plugin_dbui

    Initialize the plugin_dbui
    Define persistent storage, main services 
    and methods available on the client side.
    
"""

from gluon.storage import Storage
from gluon.tools import PluginManager
dbui = local_import('plugin_dbui')

# NOTE:
# define default configuration parameters for the plugin, 
# the application using it and the persistent storage used to tune the widgets.
# In most of the case configuration parameters are either a relative path
# to a file (static/myapp.css) or to a directory (static/css) except app_script
# and base_script which should point to a file.
#
# Default values for the plugin parameters
# All these parameters should be defined in the applications model.
# Applications value must be define in the application model
# Most of them can be either a relative path static/..., or a dir path
# or a list of paths
#
lg = dbui.get_language()

plugins = PluginManager('dbui',
                        
                        app_css=None,           # relative path static/myapp.css or dir or list
                        app_js=None,            # relative path static/src/my.js or dir or list
                        app_lg=None,            # relative path or dir or list
                        app_libmin=None,        # relative path static/myapp-min.js or dir
                        app_script=None,        # relative path static/myapp.js
                        app_script_dir=None,    # relative directory static/scripts

                        dbui_conf=URL(c='plugin_dbui', f='dbui_conf'),
                        dbui_css='static/plugin_dbui/resources/css/kde-oxygen.css',
                        dbui_js='static/plugin_dbui/src',
                        dbui_lg='static/plugin_dbui/locale/dbui-lang-%s.js' % lg,
                        dbui_libmin='static/plugin_dbui/dbui-min.js',
                        dbui_script='static/plugin_dbui/main.js',
                        
                        extjs_css='static/plugin_extjs/resources/css/ext-all.css',
                        extjs_js=['static/plugin_extjs/adapter/ext/ext-base.js',
                                  'static/plugin_extjs/ext-all-debug-w-comments.js'],
                        extjs_libmin=['static/plugin_extjs/adapter/ext/ext-base.js',
                                      'static/plugin_extjs/ext-all.js'],
                        extjs_lg='static/plugin_extjs/src/locale/ext-lang-%s.js' % lg,

                        mathjax_conf=URL(c='plugin_dbui', f='mathjax_conf'),
                        mathjax_libmin='static/plugin_mathjax/MathJax.js',

                        modifier_fields={},
                        modifier_forms={},
                        modifier_grids={},
                        modifier_stores={},
                        modifier_viewports=Storage(extjs={}),
                        
                        static_stores={})
                        

# Start common services
dbSvc = dbui.DbSvc(globals())
directSvc = dbui.DirectSvc(globals())

# activate the debug mode
# this session variable is set by the control index or debug
dbSvc.debug = session.debug
directSvc.debug = session.debug

# register method available on the client side
@directSvc.register
def getForm(tablename): 
    return dbui.to_formPanel(db[tablename])

@directSvc.register
def getGrid(tablename): 
    return dbui.to_gridPanel(db[tablename])

@directSvc.register
def getTree(node): 
    return dbui.to_tree(node)

@directSvc.register
def create(data): 
    return dbSvc.create(data)

@directSvc.register
def destroy(data): 
    return dbSvc.destroy(data)

@directSvc.register
def read(data): 
    return dbSvc.read(data)

@directSvc.register
def update(data): 
    return dbSvc.update(data)