/**
 *  A border layout with a panel and a selector.
 *  
 *  The selector is a collapsible panel appearing on the right side.
 *  It contains a set of Fields usually organized in field sets.
 *  By default the selector contains two buttons Go and Reset.
 *  
 *  The logic between the panel, the selector and the buttons 
 *  is defined in inherited class.
 *  
 *  The type of this component is xpanelwithselector.
 *  
 *  @extend: Ext.Panel
 *  
 */
Ext.namespace('App');

App.BasePanelWithSelector = Ext.extend(Ext.Panel, {
 
    /**
     * @param {Object} panel and selector configurations
     */
    panelCfg: null,
    selectorCfg: null,
    
    /**
     * configuration options for the panel and selector containers
     */
    panelBorder: false,  
    selectorCollapsible: true,
    selectorFrame: true,
    selectorSplit: true,
    selectorWidth: 300,

    /**
     * Private attribute for internationalization
     */
    textGo: 'Go',
    textReset: 'Reset',

    /**
     * constructor
     * @param {Object} config
     */
    constructor: function(config){

        var cfg,
            panel,
            selector;    

        Ext.apply(this, config);

        panel = Ext.ComponentMgr.create(this.panelCfg);
        selector = Ext.ComponentMgr.create(this.selectorCfg);

        // predefined configuration of the panel
        cfg = {
            layout: 'border',
            items: [{
                border: this.panelBorder,
                layout: 'fit',
                itemId: 'mainPanel',
                items: [panel],
                region: 'center',
            }, {
            	buttons: [{
                    ref: '../../goButton', 
                    text: this.textGo
                }, {
                    ref: '../../resetButton', 
                    text: this.textReset
                }],      
                collapsible: this.selectorCollapsible,
                defaults: {anchor: '99%'},
                frame: this.selectorFrame,
                layout: 'form',
                itemId: 'selectorPanel',
                items: [selector],
                region: 'east',
                split: this.selectorSplit,
                width: this.selectorWidth,
            }]
        };

        Ext.apply(this, cfg);
        
        // instanciate the panel
        App.BasePanelWithSelector.superclass.constructor.call(this);
    }
});

Ext.reg('xpanelwithselector', App.BasePanelWithSelector);
