/**
 * The Grid class is Ext.grid.GridPanel with a Ext.PagingToolbar
 * Many functionality can be added through grid plugins like
 * App.grid.RowEditor, ....
 * 
 * The type of this component is xgrid.
 * 
 * @extends Ext.gridPanel
 * @version
 * 
 */

Ext.namespace('App.grid');

App.grid.Grid = Ext.extend(Ext.grid.GridPanel, {

    /**
     * private attributes used by plugins
     */
    rowEditor: null,   

    /**
     * Constructor
     * 
     * NOTE:
     * Required in ExtJS 3.4 convert rownumberer xtype
     * into an Ext.grid.RowNumberer. Not needed in ExtJS 4
     * 
     */
    constructor: function (config) {

      var first_column = config.columns[0];
      
      if ('xtype' in first_column && first_column.xtype === 'rownumberer') {
        config.columns[0] = new Ext.grid.RowNumberer();    
      }
      
      Ext.apply(this, config);
      App.grid.Grid.superclass.constructor.call(this); 
    },
    /**
     * private method requests by the component model of ExtJS
     */
    initComponent: function () {

        // link the grid to the data store
        this.store = App.getStore(this.store);

        // empty toolBar requires by the plugins
        this.bbar = new Ext.Toolbar();

        // initialize the underlying class. DON'T MOVE
        App.grid.Grid.superclass.initComponent.call(this);        

        // load the store if not yet done
        // if the grid paging is used load only the first 10 rows
        if (!this.store.getTotalCount()) {
            if (App.isPlugin(this, 'pGridPaging')) {
                this.store.load({params: {start: 0, limit: 10}});
            } else {
                this.store.load();    
            }
        }
    }
});

Ext.reg('xgrid', App.grid.Grid);
