/**
 * The row editor context menu plugin
 *
 * Display the context menu when the user right click on a row.
 * The content of the menu allows to manipulate the App.grid.RowEditor
 * 
 * Requires the App.grid.GridRowEditor plugin.
 * 
 * The ptype of this component is pGridRowEditorContextMenu.
 * 
 * @extends Object
 * @version
 * 
 */

Ext.namespace('App.grid');

App.grid.RowEditorContextMenu = Ext.extend(Object, {

    /**
     * Private attribute identifying the type of plugin
     */
    ptype: 'pGridRowEditorContextMenu',

    /**
     * private attributes for internationalization
     */
    textAdd: 'Add',
    textCreate: 'Create',
    textDestroy: 'Delete',
    textDuplicate: 'Duplicate',
    textUpdate: 'Update',
    textView: 'View',
        
    /**
     * Plugin initialization
     * @param {Object} grid
     */
    init: function (grid) {
                
        var menu = new Ext.menu.Menu();
        
        // protection		
        if (!grid.rowEditor) {
            throw new Error('no grid row editor !!!');
        }

        grid.addListener('containercontextmenu', this.onContainerContextMenu, menu);
        grid.addListener('headercontextmenu', this.onHeaderContextMenu, menu);
        grid.addListener('rowcontextmenu', this.onRowContextMenu, menu);
        
        menu.add({
            text: this.textAdd,
            iconCls: 'xaction-create',
            handler: grid.rowEditor.onAddRow,
            scope: grid.rowEditor
        }, '-', {
            text: this.textDuplicate,
            iconCls: 'xaction-duplicate',
            handler: grid.rowEditor.onDuplicateRow,
            scope: grid.rowEditor
        }, {
            text: this.textUpdate,
            iconCls: 'xaction-update',
            handler: grid.rowEditor.onEditRow,
            scope: grid.rowEditor
        }, {
            text: this.textView,
            iconCls: 'xaction-view',
            handler: grid.rowEditor.onViewRow,
            scope: grid.rowEditor
        }, '-', {
            text: this.textDestroy,
            iconCls: 'xaction-destroy',
            handler: grid.rowEditor.onDeleteRow,
            scope: grid.rowEditor
        });
    },
    
    /**
     * Prvate handler displaying the row context menu in an empty grid
     */
    onContainerContextMenu: function (grid, event) {
        var menu = this;
        
        event.stopEvent();
        menu.showAt(event.getXY());
        
    },
    /**
     * Private handler displaying the context menu in the header
     * Nothing is display in that case.
     */
    onHeaderContextMenu: function (grid, columIndex, event) {
        event.stopEvent();
    },
    /**
     * Private handler displaying the row context menu
     * The scope use by the handler is the menu object.
     */
    onRowContextMenu: function (grid, rowIndex, event) {
        
        var menu = this;
        
        event.stopEvent();
        grid.selModel.selectRow(rowIndex);		
        menu.showAt(event.getXY());

    }

});

Ext.preg('pGridRowEditorContextMenu', App.grid.RowEditorContextMenu);
