/**
 * A JsonStore to read/write in the database using the EXt.Direct protocol.
 * Design to work with the class DbSvc on the server side.
 * 
 * This class is an Ext.dat.DirectStore with an Ext.data.JsonWriter.
 * 
 * Defaults configuration parameters of the writer are defined in the 
 * constructor. Changing them might break the decoding running on the 
 * server-side and break the behavior of the grid widget.
 * 
 * The default API associated to this store is defined in the constructor
 * 
 * The type of this component is xdirectstore.
 * 
 * @extends Ext.data.DirectStore
 * @version
 * *
 */
Ext.namespace('App.data');

App.data.DirectStore = Ext.extend(Ext.data.DirectStore, {
        
    /**
     * @cfg(Boolean) encode JsonWiter property, by default false
     * Changing this option might break the decoding running on the server-side
     * NOTE: the default value is defined in the constructor
     */
    /**
     * @cfg(Boolean) listful JsonWiter property, by default true
     * Changing this option might break the decoding running on the server-side
     * NOTE: the default value is defined in the constructor
     */
    /**
     * @cfg(Boolean) writeAllFields JsonWiter property, by default false
     * Changing this option might break the decoding running on the server-side
     * NOTE: the default value is defined in the constructor
     */
    /**
     * pre-defined configuration option
     * The autoSave parameter is helpful for gridRowEditor.
     */
    autoLoad: true,
    autoSave: true,
    
    /**
     * constructor
     */
    constructor: function (config) {
        
        var cfg, 
            cfgWrt;

        // configuration option with default value for 
        // the Ext.data.JsonWriter. Changing these options might break 
        // the decoding running on the server side.
        cfg = Ext.apply({}, {
            encode: false,
            listful: true,
            writeAllFields: false
        }, config);

        // define the remote procedure for store action
        cfg = Ext.apply(cfg, {
            api: {
                create: Dbui.create,
                destroy: Dbui.destroy,
                read: Dbui.read,
                update: Dbui.update
            }
        });

        // setup the writer
        if (!Ext.isDefined(cfg.writer)) {
            cfgWrt = Ext.copyTo({}, cfg, 'encode, listful, writeAllFields');
            cfg.writer = new Ext.data.JsonWriter(cfgWrt);    
        }
        
        // instantiate the store
        App.data.DirectStore.superclass.constructor.call(this, cfg);

        // update the total number of records        
        this.on('write', this.onWrite);
    },
    
    /**
     * Handler to update the total number of records after a write action
     * @param {Object} store
     * @param {Object} action
     */
    onWrite: function (store, action) {
        
        switch (action) {
        case 'create':
            store.totalLength += 1;
            break;
    
        case 'destroy':
            store.totalLength -= 1;
            break;
        }
    }
});

Ext.reg('xdirectstore', App.data.DirectStore);
