/**
 * This widget is split in two part a main panel and a selector.
 * The selector display a list of fields organized in fieldset.
 * There values define the URL parameters. The main panel displays
 * the URL content.
 * 
 * Configuration for the main panel and the selelctor are set via
 * the option panelCfg and selectorCgf.
 * 
 * The URL display in the main panel is defined by the baseUrl option.
 * It can be modified dynamicaly by extracting the name of the
 * controller, function and/or  extension from the selector fields.
 * The options ctrlField, extField and funcField associated field
 * used to determine the value.                    
 *
 * Mathematical symbols will be interpreted, if the javascript library 
 * mathjax is load. Use the isMathJax property.
 * 
 * The type of this component is xpanelwithurlselector.
 *  
 * @extends App.PanelWithSelector
 * @version
 * 
 */
Ext.namespace('App');

App.PanelWithUrlSelector = Ext.extend(App.BasePanelWithSelector, {
    
    /**
     * @param {String} baseurl well form url, i.e http://blabla
     */
    baseUrl: null,
    
    /**
     * @param {String} ctrFiedl  name of the field defining the controller
     * When define the url become baseUrl/ctrlFieldValue
     */
    ctrlField: null,
    
    /**
     * @param {String} extFiedl  name of the field defining the extension
     * When define the url become baseUrl.extFieldValue
     */
    extField: null,

    /**
     * @param {String} funcFiedl  name of the field defining the function
     * When define the url become baseUrl/funcFieldValue
     */
    funcField: null,
    
    /**
     * @param {Boolean} isMathJax True is the mathjax library is installed
     */
    isMathJax: false,
    
    /**
     * @param {Number} Timeout  timeout for the Ajax request in second
     */
    timeout: 30,
    
    /**
     * Private attributes for internationalization
     */
    textLoad: 'Loading...',
    
    /**
     * Require by the ExtJS model
     */    
    initComponent: function () {

        App.PanelWithUrlSelector.superclass.initComponent.call(this);

        // connect the buttons
        this.goButton.on('click', this.onGo, this);
        this.resetButton.on('click', this.onReset, this);
    },

    /**
     * handler to build the URL and to load it in the panel
     */
    onGo: function() {
        
        var fields,
            i,
            mainPanel = this.getComponent('mainPanel'),
            params = {},
            selector = this.getComponent('selectorPanel'),
            url = this.baseUrl,
            urlCtrl = null,
            urlFunc = null,
            urlExt = null;

        // activate the auto scrolling
        mainPanel.setAutoScroll(true);
                
        // extract basic parameters
        fields = selector.findByType('field');
        for (i = 0; i < fields.length; i += 1) {
            if(fields[i].getName() === this.ctrlField) {
                urlCtrl =  fields[i].getValue();
                
            } else if (fields[i].getName() === this.extField) {
                urlExt =  fields[i].getValue();

            } else if (fields[i].getName() === this.funcField) {
                urlFunc =  fields[i].getValue();
                    
            } else {
                params[fields[i].getName()] = fields[i].getValue();    
            }
        }

        // extract parameters embedded in composite fields 
        fields = this.findByType('compositefield');
        for (i = 0; i < fields.length; i += 1) {
            fields[i].items.eachKey(function(key, subfield) {
                params[subfield.getName()] = subfield.getValue();
            });
        }

        // build the URL
        if (urlCtrl !== null) {
            url = url + '/' + urlCtrl;
        }

        if (urlFunc !== null) {
            url = url + '/' + urlFunc;
        }

        if (urlExt !== null) {
            url = url + '.' + urlExt;
        }
        
        // load url in the main panel            
        mainPanel.load({
            callback: this.onLoad,
            params: params,
            scope: this,
            text: this.textLoad,
            url: url,
            timeout: this.timeout 
        });        
    },

    /**
     * Handler call when the web page is load in the panel.
     * It is useful to detect HTTP error and to perform post 
     * processing (MathJax).
     * 
     * Arguments ares those of the Ext.Update.update.
     * @param {Ext.Element} el the element being update
     * @param {boolean} success true for succes false for failure
     * @param {XMLHttpRequest} response
     * @param {Object} options
     */
    onLoad: function(el, success, response, options) {

        var panelWithSelector = this;

        // errors detection
        if(success === false) {
            el.updateManager.abort();
            el.update(response.responseText);
        }
        
        // post processing
        if(panelWithSelector.isMathJax) {
            MathJax.Hub.PreProcess();
            MathJax.Hub.Process();
        }
    },

    /**
     * Handler to reset the selector
     */
    onReset: function () {
        
        var fields, 
            i,
            selector = this.getComponent('selectorPanel');

        
        fields = selector.findByType('field');
        for (i = 0; i < fields.length; i += 1) {
            fields[i].reset();
        }
    }
});

Ext.reg('xpanelwithurlselector', App.PanelWithUrlSelector);
