/**
 * The Viewport for the application.
 * 
 * The type of this component is xviewport.
 * 
 * @extends Ext.Viexport
 * @version
 * 
 */
Ext.namespace('App');

App.Viewport = Ext.extend(Ext.Viewport, {

    /**
     * @cfg {boolean} logged true when the user pass the login procedure
     */
    logged: false,
    
    /**
     * private shortcuts
     */
    tabPanel: null,
    treePanel: null,
    
    /**
     * constructor 
     * @param {Object} config
     */
    constructor: function (config) {

        var cgf,
            loader,
            root,
            treePanel,
            viewport;

        Ext.apply(this, config);

        // define the root node
        root = new Ext.tree.AsyncTreeNode({
            id: 'root',
            nodeType: 'async',
            expanded: true,
            text: App.name
        });

        // define nodes loader
        loader = new Ext.tree.TreeLoader({
            directFn: Dbui.getTree
        }); 

        // predefined configuration of the view port
        cfg = {
            layout: 'border',
            title: 'Ext Layout Browser',
            items: [{
                height: 25,
                hidden: true,
                itemId: 'topBar',
                region: 'north',
                xtype: 'toolbar'
            }, {
                autoScroll: true,
                collapsible: true,
                itemId: 'treePanel',
                loader: loader,
                region: 'west',
                root: root,
                rootVisible: false,
                split: true,
                title: App.name,
                width: 200,
                xtype: 'treepanel'
            }, {
                autoScroll: true,
                defaults: {layout: 'fit'},
                enableTabScroll: true,
                itemId: 'tabPanel',
                region: 'center',
                tabPosition: 'top',
                xtype: 'tabpanel'
            }, {
                height: 25,
                hidden: true,
                itemId: 'bottomBar',
                region: 'south',
                xtype: 'toolbar'
            }]
        };

        // apply the user configuration if any
        Ext.apply(this, cfg);
        
        // instanciate the viewport
        App.Viewport.superclass.constructor.call(this);
        
        // define shortcuts
        this.tabPanel = this.getComponent('tabPanel');
        this.treePanel = this.getComponent('treePanel');
        
        // Add handler to create tab and their widget
        this.treePanel.on('click', this.onCreateTab, this);
        
        // disable contextmenu in the treepanel
        this.treePanel.on('contextmenu', function (node, event) {
            event.stopEvent();
        });
    },

    /**
     * Handler to create / activate a tab
     * The scope is the viewport
     * 
     * @param {Object} node
     * @param {Object} event
     */
    onCreateTab: function(node, event){
 
        var cfg,
            parent = node.parentNode,
            panel,
            tabId,
            viewport = this,
            wdgcfg = node.attributes.cfg,
            wdgtype = node.attributes.cfg.xtype;
     
        // protection
        if(!node.isLeaf()){
            return;
        }   

        // unique tab identifier
        tabId = node.attributes.text + '/' + wdgtype;
                
        // activate an existing tab
        if (this.tabPanel.getComponent(tabId)) {
            this.tabPanel.setActiveTab(tabId);
            return;
        }

        // tab configuration
        // the title is defined as 'Form tablename', 'Grid tablename', ...
        cfg = {
            closable: true,
            itemId: tabId,
            title: parent.attributes.text + " " + node.attributes.text
        };
        
        // embed single panel in the tab panel        
        // other widget as children
        if( wdgtype === 'panel') {
            delete wdgcfg.xtype;
            Ext.apply(cfg, wdgcfg);
            
        } else {
            cfg.items = [node.attributes.cfg];
        }
        
        // create a new tab and activate it
        panel = this.tabPanel.add(cfg);
        this.tabPanel.setActiveTab(tabId);
    }
});

Ext.reg('xviewport', App.Viewport);
